/*
   orxonox - the future of 3D-vertical-scrollers

   Copyright (C) 2004 orx

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   ### File Specific:
   main-programmer: Benjamin Grauer
   co-programmer: ...
*/

#define DEBUG_SPECIAL_MODULE DEBUG_MODULE_GUI

#include "glgui_slider.h"

namespace OrxGui
{

  /**
   * standard constructor
  */
  GLGuiSlider::GLGuiSlider ()
  {
    this->init();

  }


  /**
   * standard deconstructor
  */
  GLGuiSlider::~GLGuiSlider()
  {
  }

  /**
   * initializes the GUI-element
   */
  void GLGuiSlider::init()
  {
    this->setClassID(CL_GLGUI_SLIDER, "GLGuiSlider");
    this->_value = 0.0;
    this->_minValue = 0.0;
    this->_maxValue = 1.0;
    this->_step = 0.1;

    this->setSize2D(100, 30);
    this->resize();
  }


  void GLGuiSlider::setValue(float value)
  {
    this->_value = value;
  }

  void GLGuiSlider::setMin(float minimum)
  {
    this->_minValue = minimum;
  }

  void GLGuiSlider::setMax(float maximum)
  {
    this->_maxValue = maximum;
  }

  void GLGuiSlider::setRange(float minimum, float maximum)
  {
    this->_minValue = minimum;
    this->_maxValue = maximum;
  }

  void GLGuiSlider::setStep(float step)
  {
    this->_step = step;
  }


  void GLGuiSlider::resize()
  {
    GLGuiWidget::resize();
    this->frontRect().setTopLeft(5, this->getSizeY2D()/2.0 - 1.0);
    this->frontRect().setSize(this->getSizeX2D() - 10.0, 5);
  }

  /**
   * @brief draws the GLGuiSlider
   */
  void GLGuiSlider::draw() const
  {
    this->beginDraw();
    GLGuiWidget::draw();

    this->frontMaterial().select();
    this->drawRect(this->frontRect());

    float percentagePosition = (this->_value - this->_minValue)/( this->_maxValue - this->_minValue);

    this->drawRect(Rect2D(percentagePosition* this->getSizeX2D(), 2, 5, this->getSizeY2D() - 4));

    this->endDraw();
  }
}
